cosmpy.protos.cosmos.slashing.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.slashing.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.slashing.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.slashing.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.slashing.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.slashing.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.slashing.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query provides defines the gRPC querier service

  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static SigningInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static SigningInfos(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.slashing.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query provides defines the gRPC querier service

  Params(request, context)

    Params queries the parameters of slashing module

  SigningInfo(request, context)

    SigningInfo queries the signing info of given cons address

  SigningInfos(request, context)

    SigningInfos queries signing info of all validators

class cosmpy.protos.cosmos.slashing.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query provides defines the gRPC querier service

cosmpy.protos.cosmos.slashing.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.cosmos.slashing.v1beta1.slashing_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.slashing.v1beta1.slashing_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.slashing.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.slashing.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.slashing.v1beta1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the slashing Msg service.

  static Unjail(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.slashing.v1beta1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the slashing Msg service.

  Unjail(request, context)

    Unjail defines a method for unjailing a jailed validator, thus returning them into the bonded validator set, so they can begin receiving provisions and rewards again.

class cosmpy.protos.cosmos.slashing.v1beta1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the slashing Msg service.

cosmpy.protos.cosmos.slashing.v1beta1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents